# -*- coding: utf-8 -*-

# This code is part of Qiskit.
#
# (C) Copyright IBM 2018, 2019.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

"""Exception for the IBMQ module."""

from qiskit.exceptions import QiskitError


class IBMQError(QiskitError):
    """Base class for errors raised by the IBMQ provider module."""
    pass


class IBMQAccountError(IBMQError):
    """Base class for errors raised by account management."""
    pass


class IBMQApiUrlError(IBMQAccountError):
    """Errors raised due to mixing API versions."""


class IBMQProviderError(IBMQAccountError):
    """Errors related to provider handling."""


class IBMQBackendError(IBMQError):
    """IBM Q Backend Errors."""
    pass


class IBMQBackendValueError(IBMQBackendError, ValueError):
    """Value errors thrown within IBMQBackend."""
    pass
